pub enum FDCANLength {
Show 16 variants
BYTES_0 = 0,
BYTES_1 = 1,
BYTES_2 = 2,
BYTES_3 = 3,
BYTES_4 = 4,
BYTES_5 = 5,
BYTES_6 = 6,
BYTES_7 = 7,
BYTES_8 = 8,
BYTES_12 = 12,
BYTES_16 = 16,
BYTES_20 = 20,
BYTES_24 = 24,
BYTES_32 = 32,
BYTES_48 = 48,
BYTES_64 = 64,
}Expand description
The length of the package in bytes, can be up to 64 bytes.
pub structs must be a certain size for FDCAN to transfer The following package sizes (in bytes) are 0, 1, 2, 3, 4, 5, 6, 7, 8, 12, 16, 20, 24, 32, 48, 64.
Variants
BYTES_0 = 0
BYTES_1 = 1
BYTES_2 = 2
BYTES_3 = 3
BYTES_4 = 4
BYTES_5 = 5
BYTES_6 = 6
BYTES_7 = 7
BYTES_8 = 8
BYTES_12 = 12
BYTES_16 = 16
BYTES_20 = 20
BYTES_24 = 24
BYTES_32 = 32
BYTES_48 = 48
BYTES_64 = 64